@@ -17,7 +17,6 @@ import socket
 import stat
 import struct
 import subprocess
-import tempfile
 import textwrap
 import threading
 import time
@@ -544,17 +543,16 @@ class AdbDevice(BaseDevice):
     def screenshot(self) -> Image.Image:
         """ not thread safe """
         try:
-            inner_tmp_path = "/sdcard/tmp001.png"
-            self.shell(['rm', inner_tmp_path])
-            self.shell(["screencap", "-p", inner_tmp_path])
-
-            with tempfile.TemporaryDirectory() as tmpdir:
-                target_path = os.path.join(tmpdir, "tmp001.png")
-                self.sync.pull(inner_tmp_path, target_path)
-                im = Image.open(target_path)
-                im.load()
-                self._width, self._height = im.size
-                return im.convert("RGB")
+            conn = self.shell(["screencap", "-p"], stream=True)
+            raw_png = b''
+            while True:
+                chunk = conn.read(4096)
+                if not chunk:
+                    break
+                raw_png += chunk
+            im = Image.open(io.BytesIO(raw_png))
+            self._width, self._height = im.size
+            return im.convert("RGB")
         except UnidentifiedImageError:
             w, h = self.window_size()
             return Image.new("RGB", (w, h), (220, 120, 100))
@@ -764,14 +762,15 @@ class AdbDevice(BaseDevice):
         if main_activity and main_activity.find(".") == -1:
             main_activity = "." + main_activity
 
-        version_name = apk.manifest.version_name
+        version_code = apk.manifest.version_code
         _dprint("packageName:", package_name)
         _dprint("mainActivity:", main_activity)
-        _dprint("apkVersion: {}".format(version_name))
+        _dprint("apkVersion: {}".format(apk.manifest.version_name))
         _dprint("Success pushed, time used %d seconds" % (time.time() - start))
 
         new_dst = "/data/local/tmp/{}-{}.apk".format(package_name,
-                                                     version_name)
+                                                     version_code)
+        _dprint("Rename to {}".format(new_dst))
         self.shell(["mv", dst, new_dst])
 
         dst = new_dst
